@@ -37,6 +37,7 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
         ("type", config_options.Type(str, default="date")),
         ("timezone", config_options.Type(str, default="UTC")),
         ("exclude", config_options.Type(list, default=[])),
+        ("enable_creation_date", config_options.Type(bool, default=False)),
     )
 
     def on_config(self, config: config_options.Config, **kwargs) -> Dict[str, Any]:
@@ -147,11 +148,12 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
             logging.debug("Excluding page " + page.file.src_path)
             return markdown
 
-        revision_dates = self.util.get_revision_date_for_file(
-            path=page.file.abs_src_path,
-            locale=self.config.get("locale", "en"),
-            time_zone=self.config.get("time_zone", "UTC"),
-            fallback_to_build_date=self.config.get("fallback_to_build_date"),
+        # revision date
+        revision_dates = self.util.get_date_formats_for_timestamp(
+            commit_timestamp=self.util.get_git_commit_timestamp(
+                path=page.file.abs_src_path,
+                is_first_commit=False,
+            )
         )
         revision_date = revision_dates[self.config["type"]]
 
@@ -161,14 +163,42 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
         if self.config["type"] == "timeago":
             revision_date += revision_dates["iso_date"]
 
+        # Add to page meta information
         page.meta["git_revision_date_localized"] = revision_date
-        return re.sub(
-            r"\{\{\s*[page\.meta\.]*git_revision_date_localized\s*\}\}",
+        # Replace any occurances in markdown page
+        markdown = re.sub(
+            r"\{\{\s*git_revision_date_localized\s*\}\}",
             revision_date,
             markdown,
             flags=re.IGNORECASE,
         )
 
+        # Creation date
+        if self.config.get("enable_creation_date"):
+            creation_dates = self.util.get_date_formats_for_timestamp(
+                commit_timestamp=self.util.get_git_commit_timestamp(
+                    path=page.file.abs_src_path,
+                    is_first_commit=True,
+                )
+            )
+            creation_date = creation_dates[self.config["type"]]
+
+            # timeago output is dynamic, which breaks when you print a page
+            # This ensures fallback to type "iso_date"
+            # controlled via CSS (see on_post_build() event)
+            if self.config["type"] == "timeago":
+                creation_date += creation_dates["iso_date"]
+
+            page.meta["git_creation_date_localized"] = creation_date
+            markdown = re.sub(
+                r"\{\{\s*git_creation_date_localized\s*\}\}",
+                creation_date,
+                markdown,
+                flags=re.IGNORECASE,
+            )
+
+        return markdown
+
     def on_post_build(self, config: Dict[str, Any], **kwargs) -> None:
         """
         Run on post build.
